********
NengoSPA
********

NengoSPA is an implementation of the Semantic Pointer Architecture for Nengo.
The :doc:`Semantic Pointer Architecture <user-guide/spa-intro>` provides an
approach to building cognitive models implemented with large-scale spiking
neural networks.


.. toctree::
   :maxdepth: 2

   getting-started
   user-guide
   examples
   api
   developer
